ScannerCommand class

A class representing a scanner command, inheriting from BaseCommand.

This class is used to create specific scanner commands with optional parameters for LED, buzzer, and vibration feedback.

Constructors

ScannerCommand(String code, {List<String> parameters = const [], bool sendFeedback = true, bool? ledFeedback, bool? buzzerFeedback, bool? vibrationFeedback})
Constructs a ScannerCommand with the given command code and optional feedback settings.

Properties

buzzerFeedback → bool?
finalinherited
code → String
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
ledFeedback → bool?
finalinherited
parameters → List<String>
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sendFeedback → bool
finalinherited
vibrationFeedback → bool?
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited