Code93 class abstract

Interface for managing Code 93 symbology settings.

Provides methods for enabling or disabling check digit validation and concatenation options for Code 93.

Constructors

Code93()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setCheckCD({required String deviceId, required bool enabled}) → Future<CommandResponse>
Sets the check digit validation for Code 93 symbology.
setConcatenation({required String deviceId, required bool enabled}) → Future<CommandResponse>
Sets the concatenation mode for Code 93 symbology.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited