ConnectionPool class abstract

Manages connection pool settings for BLE devices.

Connection Pooling allows exclusive connections of scanners to devices by using a 4-character hexadecimal ID. This ensures secure, automatic connections in environments with multiple scanners across different devices.

Constructors

ConnectionPool()

Properties

hashCode → int
The hash code for this object.
no setterinherited
reservedIds → List<String>
A list of reserved 4-character hexadecimal IDs that cannot be used for connection pooling.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

cacheId(String deviceId, String poolId) → void
Caches the connection pool ID for the specified device. This is used to store the connection pool ID for a device without setting it. It will be called automatically whenever setId is executed to update the cache.
getConnectionPoolQRData(String poolId) → String
Generates a configuration command string that can be encoded into a QR code.
getId(String deviceId) → String
Retrieves the connection pool ID of the specified device.
isValidId(String poolId) → bool
Checks if the given ID is a valid 4-character hexadecimal value.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
resetId(String deviceId) → Future<CommandResponse>
Sends the reset command to the device, resetting the connection pool ID to '0000'.
setId({required String deviceId, required String poolId}) → Future<CommandResponse>
Sets the connection pool ID to the specified 4-character hexadecimal value.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited