GS1Databar class abstract

Interface for settings related to GS1 Databar symbology.

Provides methods to manage the transmission of check digits and AI (Application Identifier) settings.

Constructors

GS1Databar()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setTransmitAI({required String deviceId, required bool enabled}) → Future<CommandResponse>
setTransmitCD({required String deviceId, required bool enabled}) → Future<CommandResponse>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited