MSIPlessey class abstract

Interface for settings related to MSI Plessey symbology.

Provides methods to manage check digit validation and transmission settings.

Constructors

MSIPlessey()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setCDTransmission({required String deviceId, required MSIPlesseyCDTransmissionSettings setting}) → Future<CommandResponse>
setCheckCD({required String deviceId, required MSIPlesseyCheckCDSettings setting}) → Future<CommandResponse>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited